###############################################################################
# Name: ed_projinfo.py                                                        #
# Purpose: Global project information                                         #
# Author: Cody Precord <cprecord@editra.org>                                  #
# Copyright: (c) 2008 Cody Precord <staff@editra.org>                         #
# License: wxWindows License                                                  #
###############################################################################

"""Editra Project information module"""

__author__ = "Cody Precord <cprecord@editra.org>"
__svnid__ = "$Id: info.py 52439 2008-03-11 08:53:25Z CJP $"
__revision__ = "$Revision: 52439 $"


AUTHOR = 'Cody Precord'
VERSION = '0.2.90'
PROG_NAME = 'Editra'
HOME_PAGE = "http://editra.org"
I18N_PAGE = "https://translations.launchpad.net/editra/trunk/+pots/editra"
CONTACT_MAIL = "staff@editra.org"
